pub enum LogOutput {
Stdout,
Stderr,
File(PathBuf),
}Expand description
The log output.
This can be either stdout, stderr, or a file path.
The Deserialize implementation allows for the configuration file to
specify the output location as a string, which is then parsed into the
appropriate enum variant. If the string is not recognized to be either
stdout or stderr, it is assumed to be a file path.
Variants
Implementations
Sourceimpl LogOutput
impl LogOutput
Sourcepub fn as_make_writer(&self) -> BoxMakeWriter
pub fn as_make_writer(&self) -> BoxMakeWriter
Get a BoxMakeWriter for the log output.
This can be used to plug the log output into the tracing subscriber.